@@ -7,13 +7,13 @@ from qa_data_manager.data_base_model import Consultations
 
 class GenerateConsultation:
 
-    def __init__(self, doctor, patient, service, slot):
+    def __init__(self, doctor, patient, service, slot, external_id):
         self._created_at = mytime.datetime.now()
         self._deleted_at = None
         self._doctor = doctor.get('id')
-        self._start_at = slot.get('start_at')
+        self._start_at = slot.start_at
         self._end_at = self._start_at + mytime.timedelta(minutes=int(service.get('duration')))
-        self._external_id = None
+        self._external_id = external_id
         self._external_type = 'slot'
         self._patient = patient.get('id')
         self._pay_source = 'online'
@@ -26,10 +26,6 @@ class GenerateConsultation:
         self._deleted_at = mytime.datetime.now()
         return self
 
-    def with_external_id(self, ex_id):
-        self._external_id = ex_id
-        return self
-
     def with_external_type_service_patient(self):
         self._external_type = 'service_patient'
 
