@@ -1,10 +1,10 @@
 from datetime import datetime
 
 from qa_data_manager.data_base_model import SlotsDoctors, ConfirmationCodes, Users, DoctorPatient, Chats, ClinicUser, \
-    Clinics
+    Clinics, Services
 
 
-class Slot_doctor_table:
+class SlotDoctorTable:
     # Вся строка из таблицы по id слота
     def slot_info_by_id(self, slot_id):
         return SlotsDoctors.select().where(SlotsDoctors.id == slot_id).get()
@@ -21,7 +21,7 @@ class Slot_doctor_table:
     def first_slot_info_by_list_of_slots_ids(self, slots_ids):
         return SlotsDoctors.select().where(SlotsDoctors.id == slots_ids[0]).get()
 
-    # Дата и время начала определенного слота по id
+    # Дата и время всех слотов на определенный день
     def list_of_slots_start_at_by_day_and_gen_person(self, day, gen_doctor):
         slots_list_bd = []
         slots_bd = SlotsDoctors.select().where(
@@ -30,8 +30,16 @@ class Slot_doctor_table:
             slots_list_bd.append(datetime.strftime((s.start_at), "%H:%M"))
         return slots_list_bd
 
+    # Дата и время всех слотов на определенный день
+    def list_of_slots_start_at_by_gen_person(self, gen_doctor):
+        slots_list_bd = []
+        slots_bd = self.slot_info_by_doctor(gen_doctor)
+        for s in slots_bd.objects():
+            slots_list_bd.append(datetime.strftime((s.start_at), "%H:%M"))
+        return slots_list_bd
 
-class Users_table:
+
+class UserTable:
     # Вся строка из таблицы по сгенерированному пользователю
     def info_by_gen_person(self, person):
         return Users.select().where(Users.phone == person.get('phone')).get()
@@ -54,7 +62,7 @@ class Users_table:
             Users.deleted_at.is_null())).count()
 
 
-class Confirmation_codes_table():
+class ConfirmationCodesTable:
     # Код по пользователю через запрос к БД
     def get_code_by_req_person(self, person):
         return ConfirmationCodes.select().where(ConfirmationCodes.user_id == person.id).get().code
@@ -64,7 +72,7 @@ class Confirmation_codes_table():
         return ConfirmationCodes.select().where(ConfirmationCodes.user_id == person.get("id")).get().code
 
 
-class Doctor_patient_table():
+class DoctorPatientTable:
     # Кол-во записей между id двух пользователей через сгенерированного доктора и запрос к БД по пациенту
     def count_of_value_by_gen_doc_req_pat(self, doctor, patient):
         return DoctorPatient.select().where(
@@ -76,7 +84,7 @@ class Doctor_patient_table():
             (DoctorPatient.doctor == doctor.get('id')) & (DoctorPatient.patient == patient.get('id'))).count()
 
 
-class Chats_table():
+class ChatsTable:
     # Кол-во записей между id двух пользователей через сгенерированного доктора и запрос к БД по пациенту
     def count_of_value_by_gen_doc_req_pat(self, doctor, patient):
         return Chats.select().where(
@@ -88,13 +96,13 @@ class Chats_table():
             (Chats.doctor == doctor.get('id')) & (Chats.patient == patient.get('id'))).count()
 
 
-class Clinic_user_table():
+class ClinicUserTable:
     # id клиники по сгенерированному пользователю
     def clinic_id_by_gen_person(self, person):
         return ClinicUser.select().where(ClinicUser.user == person.get("id")).get().clinic
 
 
-class Clinic_table():
+class ClinicTable:
     # Название клиники по id клиники
     def name_by_clinic_id(self, clinic_id):
         return Clinics.select().where(Clinics.id == clinic_id).get().name
@@ -112,3 +120,9 @@ class Clinic_table():
     def address_by_gen_clinic(self, gen_clinic):
         info = Clinics.select().where(Clinics.id == gen_clinic.get("id")).get()
         return info.city + ", " + info.street
+
+
+class ServicesTable:
+    # Деактивация тарифа
+    def deactivate_tariff(self, tariff):
+        Services.update(active=0).where(Services.id == tariff.get("id")).execute()
